Usage — PyGeneBe 0.14.0 documentation

# Usage

## GeneBe Utils

GeneBe: A Python client seamlessly integrating with the GeneBe platform, offering efficient annotation of genetic variants through its API, while supporting pandas, VCF file formats, and HGVS parsing.

Using this client, you can easily annotate your DNA variants with the GeneBe API. Annotations include:

- Gene, transcript, and effect

- ClinVar phenotype

- GnomAD frequency

- ACMG score

- … if you need more, please let us know

## Command Line Usage

Check current options using –help switch:

    genebe --help
    genebe annotate --help

### Annotating VCF using annotate command

GeneBe client allows you to annotate your VCF file with ease. Use the following command:

    genebe annotate --input input.vcf.gz --output output.vcf.gz

Remember that your VCF file must be in a single allelic format! Utilize bcftools (https://samtools.github.io/bcftools/) to split the file. The output VCF will contain additional fields.

To use VCF annotation, you have to have the cyvcf2 package installed. Take a look at the Installation section below.

If your VCF file is large (over 10,000 variants), you may encounter request limits. To avoid this, create a GeneBe account with an API Key and provide your login/key using the –username and –api-key arguments. You can always check your limits with the account command. Update your annotation command as follows:

    genebe annotate --input input.vcf.gz --output output.vcf.gz --username your_username --api-key your_api_key

For more information, call:

    genebe annotate --help